# © 2022 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import api, fields, models, tools


class AccountInvoiceEmployeeReport(models.Model):
    _name = "account.invoice.employee.report"
    _description = "Vue facturation par employé"
    _auto = False

    # invoice fields
    date_invoice = fields.Date("Date", readonly=True)
    invoice_id = fields.Many2one(
        comodel_name="account.invoice",
        string="Facture",
        readonly=True,
    )
    amount_untaxed_signed = fields.Monetary("Facturé H.T", readonly=True)
    production_amount = fields.Monetary("Production H.T", readonly=True)
    state = fields.Selection(
        [
            ("open", "Ouverte"),
            ("in_payment", "En paiement"),
            ("paid", "Payée"),
        ],
        string="Statut",
        readonly=True,
    )
    user_id = fields.Many2one(
        comodel_name="res.users",
        string="Vendeur",
        readonly=True,
    )
    currency_id = fields.Many2one("res.currency", string="Currency", readonly=True)
    # employee fields
    partner_id = fields.Many2one(
        comodel_name="res.partner",
        string="Employé",
        readonly=True,
    )
    percentage = fields.Float("Pourcentage", readonly=True)
    revenue = fields.Monetary("Affectation CA", readonly=True)

    _depends = {
        "account.invoice": [
            "state",
            "user_id",
            "amount_untaxed_signed",
            "date_invoice",
            "production_amount",
        ],
        "account.invoice.employee.assign": [
            "partner_id",
            "percentage",
        ],
    }

    # ------------------------------------------------------
    # Main Query
    # ------------------------------------------------------
    def _query(self):
        query = """
            SELECT
                e.id,
                i.id as "invoice_id",
                i.date_invoice,
                i.production_amount,
                i.amount_untaxed_signed,
                i.state,
                i.user_id,
                i.currency_id,
                e.partner_id,
                e.percentage,
                i.production_amount * e.percentage / 100 as "revenue"
            FROM
                account_invoice_employee_assign e
            LEFT JOIN
                account_invoice i on i.id = e.invoice_id
            WHERE
                i.date_invoice is not null
                and i.state in ('open', 'in_payment', 'paid')
                and i.type in ('out_invoice', 'out_refund')
        """
        return query

    @api.model_cr
    def init(self):
        tools.drop_view_if_exists(self.env.cr, self._table)
        self.env.cr.execute(
            """CREATE or REPLACE VIEW %s as (
            %s
        )"""
            % (self._table, self._query())
        )

    # ------------------------------------------------------
    # Computed fields
    # ------------------------------------------------------
